# PyKantorovich

<!-- badges: start -->
[![Documentation status](https://readthedocs.org/projects/pykantorovich/badge/)](http://pykantorovich.readthedocs.io)
<!-- badges: end -->

Kantorovich distance with Python.

___

```
pip install pykantorovich
```
